@@ -9,14 +9,17 @@ SUPPORTED_EXTENSIONS = (".wav",)
 
 
 def find_audio_files(
-    root_path, filename_endings=SUPPORTED_EXTENSIONS, traverse_subdirectories=True
+    root_path,
+    filename_endings=SUPPORTED_EXTENSIONS,
+    traverse_subdirectories=True,
+    follow_symlinks=True,
 ):
     """Return a list of paths to all audio files with the given extension(s) in a directory.
     Also traverses subdirectories by default.
     """
     file_paths = []
 
-    for root, dirs, filenames in os.walk(root_path):
+    for root, dirs, filenames in os.walk(root_path, followlinks=follow_symlinks):
         filenames = sorted(filenames)
         for filename in filenames:
             input_path = os.path.abspath(root)
